@@ -1,6 +1,7 @@
 import os
 
 import pytest
+import socket
 
 from fa_common.auth import AuthUser
 from fa_common.workflow import get_workflow_client
@@ -12,8 +13,10 @@ env_file = os.path.join(dirname, ".env")
 secrets_env_file = os.path.join(dirname, ".env.secret")
 minio_env_file = os.path.join(dirname, ".env-minio")
 
-TEST_GITLAB_PROJECT = "test_user"
+hostname = socket.gethostname().replace("_", "-").replace(".", "-").lower()
+TEST_GITLAB_PROJECT = f"test-user-{hostname}"
 TEST_GITLAB_BRANCH = "test_project"
+TEST_USER_BUCKET = f"test-user-{hostname}"
 
 
 def get_env_file() -> str:
@@ -57,11 +60,11 @@ def ensure_no_test_gitlab():
 def ensure_test_gitlab():
     client = get_workflow_client()
     try:
-        return (force_sync(client._get_project_by_name)("test_user")).id
+        return (force_sync(client._get_project_by_name)(TEST_GITLAB_PROJECT)).id
     except Exception as err:
         LOG.info(err)
-        project_id = force_sync(client.create_project)("test_user")
-        force_sync(client.create_branch)(project_id, "test_project")
+        project_id = force_sync(client.create_project)(TEST_GITLAB_PROJECT)
+        force_sync(client.create_branch)(project_id, TEST_GITLAB_BRANCH)
         return project_id
 
 
@@ -94,7 +97,7 @@ def pytest_runtest_setup(item):
 
 async def get_test_user() -> AuthUser:
     payload = {
-        "sub": "test-sub",
+        "sub": f"{hostname}-sub",
         "name": "Test User",
         "email": "test.user@test.com",
         "nickname": "test.user",
